@@ -207,8 +207,6 @@ static void clcc_poll_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	unsigned int num_active = 0;
 	unsigned int num_held = 0;
 
-	dump_response("clcc_poll_cb", ok, result);
-
 	if (!ok)
 		return;
 
@@ -300,7 +298,6 @@ static void generic_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	struct voicecall_data *vd = ofono_voicecall_get_data(req->vc);
 	struct ofono_error error;
 
-	dump_response("generic_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (ok && req->affected_types) {
@@ -330,8 +327,6 @@ static void atd_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	struct ofono_call *call;
 	GSList *l;
 
-	dump_response("atd_cb", ok, result);
-
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok)
@@ -374,9 +369,9 @@ static void hfp_dial(struct ofono_voicecall *vc,
 
 	cbd->user = vc;
 	if (ph->type == 145)
-		sprintf(buf, "ATD+%s", ph->number);
+		snprintf(buf, sizeof(buf), "ATD+%s", ph->number);
 	else
-		sprintf(buf, "ATD%s", ph->number);
+		snprintf(buf, sizeof(buf), "ATD%s", ph->number);
 
 	if ((clir != OFONO_CLIR_OPTION_DEFAULT) ||
 			(cug != OFONO_CUG_OPTION_DEFAULT))
@@ -497,7 +492,6 @@ static void release_id_cb(gboolean ok, GAtResult *result,
 	struct voicecall_data *vd = ofono_voicecall_get_data(req->vc);
 	struct ofono_error error;
 
-	dump_response("release_id_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (ok)
@@ -526,7 +520,7 @@ static void hfp_release_specific(struct ofono_voicecall *vc, int id,
 	req->data = data;
 	req->id = id;
 
-	sprintf(buf, "AT+CHLD=1%d", id);
+	snprintf(buf, sizeof(buf), "AT+CHLD=1%d", id);
 
 	if (g_at_chat_send(vd->chat, buf, none_prefix,
 				release_id_cb, req, g_free) > 0)
@@ -546,7 +540,7 @@ static void hfp_private_chat(struct ofono_voicecall *vc, int id,
 	char buf[32];
 
 	if (vd->ag_mpty_features & AG_CHLD_2x) {
-		sprintf(buf, "AT+CHLD=2%d", id);
+		snprintf(buf, sizeof(buf), "AT+CHLD=2%d", id);
 
 		hfp_template(buf, vc, generic_cb, 0, cb, data);
 
@@ -642,8 +636,6 @@ static void ccwa_notify(GAtResult *result, gpointer user_data)
 	int num_type, validity;
 	struct ofono_call *call;
 
-	dump_response("ccwa_notify", TRUE, result);
-
 	/* CCWA can repeat, ignore if we already have an waiting call */
 	if (g_slist_find_custom(vd->calls,
 				GINT_TO_POINTER(CALL_STATUS_WAITING),
@@ -666,7 +658,7 @@ static void ccwa_notify(GAtResult *result, gpointer user_data)
 	else
 		validity = 2;
 
-	ofono_debug("ccwa_notify: %s %d %d", num, num_type, validity);
+	DBG("ccwa_notify: %s %d %d", num, num_type, validity);
 
 	call = create_call(vc, 0, 1, 5, num, num_type, validity);
 
@@ -709,8 +701,6 @@ static void ring_notify(GAtResult *result, gpointer user_data)
 	struct ofono_call *call;
 	GSList *waiting;
 
-	dump_response("ring_notify", TRUE, result);
-
 	/* RING can repeat, ignore if we already have an incoming call */
 	if (g_slist_find_custom(vd->calls,
 				GINT_TO_POINTER(CALL_STATUS_INCOMING),
@@ -762,8 +752,6 @@ static void clip_notify(GAtResult *result, gpointer user_data)
 	GSList *l;
 	struct ofono_call *call;
 
-	dump_response("clip_notify", TRUE, result);
-
 	l = g_slist_find_custom(vd->calls,
 				GINT_TO_POINTER(CALL_STATUS_INCOMING),
 				at_util_call_compare_by_status);
@@ -795,7 +783,7 @@ static void clip_notify(GAtResult *result, gpointer user_data)
 	g_at_result_iter_skip_next(&iter);
 	g_at_result_iter_skip_next(&iter);
 
-	ofono_debug("clip_notify: %s %d %d", num, type, validity);
+	DBG("clip_notify: %s %d %d", num, type, validity);
 
 	call = l->data;
 
@@ -880,7 +868,6 @@ static void sync_dialing_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	struct ofono_call *oc;
 	struct ofono_call *nc;
 
-	dump_response("sync_dialing_cb", ok, result);
 	decode_at_error(&error, g_at_result_final_response(result));
 
 	if (!ok)
@@ -1120,7 +1107,7 @@ static void hfp_voicecall_initialized(gboolean ok, GAtResult *result,
 	struct ofono_voicecall *vc = user_data;
 	struct voicecall_data *vd = ofono_voicecall_get_data(vc);
 
-	ofono_debug("hfp_voicecall_init: registering to notifications");
+	DBG("hfp_voicecall_init: registering to notifications");
 
 	g_at_chat_register(vd->chat, "RING", ring_notify, FALSE, vc, NULL);
 	g_at_chat_register(vd->chat, "+CLIP:", clip_notify, FALSE, vc, NULL);
